==> haskell-here-1.2.13-252-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 here
version:              1.2.13
visibility:           public
id:                   here-1.2.13-2NmeyhHe7OaGMZVN7I9XLo
key:                  here-1.2.13-2NmeyhHe7OaGMZVN7I9XLo
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  eab7024bd8fb224ed7e386e0b1ee3c48
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/here-1.2.13
library-dirs:         /usr/lib/ghc-9.0.1/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/here-1.2.13
hs-libraries:         HShere-1.2.13-2NmeyhHe7OaGMZVN7I9XLo
depends:
    base-4.15.0.0 haskell-src-meta-0.8.7-IMRTWpJDEvFdYBpUWEFWM
    mtl-2.2.2 parsec-3.1.14.0 template-haskell-2.17.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.13-254-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 here
version:              1.2.13
visibility:           public
id:                   here-1.2.13-BbsX6DH0NQcFyXuH4F7t7W
key:                  here-1.2.13-BbsX6DH0NQcFyXuH4F7t7W
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  27243595139913f7652b1d00cee6ba5d
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/here-1.2.13
library-dirs:         /usr/lib/ghc-9.0.1/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/here-1.2.13
hs-libraries:         HShere-1.2.13-BbsX6DH0NQcFyXuH4F7t7W
depends:
    base-4.15.0.0 haskell-src-meta-0.8.7-H1zwwQr03DHfgyfZfwBvc
    mtl-2.2.2 parsec-3.1.14.0 template-haskell-2.17.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
